# frozen_string_literal: true

require 'cht-chaphql'
require 'cht-chaphql/graphql_formatters'

CQS_ADAPTER_FMTRS =
  YAML.load_file(File.join(__dir__, '../helpers/formatters.yml'))

# module for cqs-adapter
module ChtApitestCqsAdapter
  include Chaphql
  include Chaphql::GraphQLHelpers

  # module for your shortcuts
  module CqsAdapterHelpers
    def via_public
      %w[staging canary prod].include?(getenv)
    end

    def auth_service
      LocalAuthService.new(via_public: via_public)
    end
    # insertion point for shortcuts
    # end of shortcut insertion
  end

  # class for your service
  class CqsAdapterService < ChtNgService
    include RSpec::Matchers

    CQS_ADAPTER_DEFAULTS = {
      name: 'CqsAdapter',
      default_namespace: 'cqs-adapter',
      service_name: 'cqs-adapter',
      pr_parent: 'cqs-adapter',
      formatters: CQS_ADAPTER_FMTRS['formatters'],
      v2_checkers: CQS_ADAPTER_FMTRS['v2_checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(CQS_ADAPTER_DEFAULTS))
    end
  end

  # class for api-proxy support of cqs-adapter service
  class ApiProxyCqsAdapter < ChtNgService
    include RSpec::Matchers

    API_PROXY_DEFAULTS = {
      name: 'ApiProxyCqsAdapter',
      default_namespace: 'api-proxy',
      service_name: 'api-proxy',
      pr_parent: 'api-proxy',
      formatters: CQS_ADAPTER_FMTRS['formatters'],
      v2_checkers: CQS_ADAPTER_FMTRS['v2_checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(API_PROXY_DEFAULTS))
    end
  end
end
