# frozen_string_literal: true

require 'spec_helper'

describe 'CqsAdapter' do
  include_context 'request metadata'

  it 'can make a rest call to the cqs-adapter api for querying metadata' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_BODY_METADATA_ONLY
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube Metadata for #{CUBE_IDENTIFIER[cloud_type][granularity]}"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << 'CQS Adapter Response Validation failed' unless validate.cqs_adapter_metadata(value)
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end
end
