# frozen_string_literal: true

require 'spec_helper'

describe 'CqsAdapter SkipFeatureFlagCheck Set to False' do
  include_context 'request metadata'

  it 'Cost History: should not fall back to CQS WHEN NO EXPLICIT ORG ENTRY IN REDIS with CustomerId#OrgId' do
    failures = []
    SUB_OU_WITH_NO_EXPLICIT_ORG_ENTRY.keys.each do |cloud_type|
      SUB_OU_WITH_NO_EXPLICIT_ORG_ENTRY[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_BODY_METADATA_ONLY
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Metadata for #{SUB_OU_WITH_NO_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=false"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{SUB_OU_WITH_NO_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "METADATA RESPONSE TOP LEVEL KEYS MISMATCH FOR IDENTIFIER: #{SUB_OU_WITH_NO_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "Checking FlexQuery Datasource for Identifier: #{SUB_OU_WITH_NO_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}" unless validate.get_flex_query_data_source_from_response.eql? 'AWS_COST_HISTORY'
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end

  it 'Cost History: should not fall back to CQS WITH EXPLICIT ORG ENTRY IN REDIS with CustomerId#OrgId' do
    failures = []
    SUB_OU_WITH_EXPLICIT_ORG_ENTRY.keys.each do |cloud_type|
      SUB_OU_WITH_EXPLICIT_ORG_ENTRY[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_BODY_METADATA_ONLY
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Metadata for #{SUB_OU_WITH_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=false"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{SUB_OU_WITH_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "METADATA RESPONSE TOP LEVEL KEYS MISMATCH FOR IDENTIFIER: #{SUB_OU_WITH_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "Checking FlexQuery Datasource for Identifier #{SUB_OU_WITH_EXPLICIT_ORG_ENTRY[cloud_type][granularity]}" unless validate.get_flex_query_data_source_from_response.eql? 'AWS_COST_HISTORY'
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end
end
