# frozen_string_literal: true

require 'spec_helper'

describe 'CqsAdapter' do
  include_context 'request metadata'

  it 'can make a rest call to the cqs-adapter api for querying olap all granularities one dimension' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_COST_ONLY
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube data for #{CUBE_IDENTIFIER[cloud_type][granularity]} with time dimension"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "CQS Adapter Response Validation failed for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "CQS Adapter Response Validation failed for key 'csv_result_inline' for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.key_not_null?('csv_result_inline')
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end

  it 'can make a rest call to the cqs-adapter api for querying olap all granularities 2 dimension: SERVICE CATEGORY' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_SERVICE_CATEGORY
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube data for #{CUBE_IDENTIFIER[cloud_type][granularity]} with time dimension and service category"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "CQS Adapter Response Validation failed for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "CQS Adapter Response Validation failed for key 'csv_result_inline' for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.key_not_null?('csv_result_inline')
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end

  it 'can make a rest call to the cqs-adapter api for querying olap all granularities 2 dimension: ACCOUNTS' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_ACCOUNT
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube data for #{CUBE_IDENTIFIER[cloud_type][granularity]} with time dimension and accounts"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "CQS Adapter Response Validation failed for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "CQS Adapter Response Validation failed for key 'csv_result_inline' for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.key_not_null?('csv_result_inline')
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end

  it 'can make a rest call to the cqs-adapter api for querying olap all granularities 2 dimension: BILLING ACCOUNTS' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_BILLING_ACCOUNT
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube data for #{CUBE_IDENTIFIER[cloud_type][granularity]} with time dimension and billing accounts"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "CQS Adapter Response Validation failed for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "CQS Adapter Response Validation failed for key 'csv_result_inline' for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.key_not_null?('csv_result_inline')
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end

  it 'can make a rest call to the cqs-adapter api for querying olap all granularities 2 dimension: REGIONS' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_REGION
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube data for #{CUBE_IDENTIFIER[cloud_type][granularity]} with time dimension and regions"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "CQS Adapter Response Validation failed for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "CQS Adapter Response Validation failed for key 'csv_result_inline' for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.key_not_null?('csv_result_inline')
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end


  it 'can make a rest call to the cqs-adapter api for querying olap all granularities 2 dimensions: CHARGE TYPE' do
    failures = []
    CUBE_IDENTIFIER.keys.each do |cloud_type|
      CUBE_IDENTIFIER[cloud_type].each do |granularity, value|
        body = CQS_REQUEST_CHARGE_TYPE
        url = url(service: service).gsub('/graphql', '').rstrip
        url += CQS_ADAPTER_ENDPOINT
        puts "Sending Request to Fetch Cube data for #{CUBE_IDENTIFIER[cloud_type][granularity]} with time dimension and charge type"
        url += "identifier=#{value}&use_spark_cubes=true&ver=3&skipFFCheckToRouteToCqs=true"
        headers = { 'content-type': 'application/json' }
        resp = rest_call('post', url, body, headers, mocked: false)
        validate = Validate.new(resp)
        failures << "Fetching CQS METADATA VIA CQS ADAPTER FAILED FOR #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.response_code(resp)
        failures << "CQS Adapter Response Validation failed for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.cqs_adapter_response_keys
        failures << "CQS Adapter Response Validation failed for key 'csv_result_inline' for #{CUBE_IDENTIFIER[cloud_type][granularity]}" unless validate.key_not_null?('csv_result_inline')
      end
    end
    raise("Errors Occurred When Fetching Cube Metadata: #{failures}") unless failures.empty?
  end
end
